@@ -1,10 +1,11 @@
+from lib2to3.pgen2.token import OP
 import time
 import os
 import sys
 import re
 import random
 import pandas
-from flask import Flask
+import flask
 
 class OpenFlask:
     def __init__(self, app_name, flask_options, config_options={"SECRET_KEY": "s"}):
@@ -12,4 +13,10 @@ class OpenFlask:
         #for flask_opt in flask_options:
             #listofFlaskOpt.append({flask_opt['name']: flask_opt['value']})
 
-        self.app = Flask(app_name, pandas.json_normalize(flask_options))
+        self.app = flask.Flask(app_name, pandas.json_normalize(flask_options))
+    
+    def run(self, host='0.0.0.0', port=8080, debug=False):
+        self.app.run()
+
+app = OpenFlask('app', {}, {})
+app.run()
